import Vue from 'vue';
import Vuex from 'vuex';
import VueJsonp from 'vue-jsonp'

//各个模块的store
import infoState from './YiStore/yiInfo.js';

import searchStore from './YiStore/yisearch.js';

import studyStore from './YiStore/yistudy.js';

import leaveStore from './YiStore/yileave.js';


Vue.use(Vuex);
Vue.use(VueJsonp);

let gridIcon = require('../assets/icon_nav_article.png');
export default new Vuex.Store({

    state: {
        categoryKey: 'recommend',
        categories: [
            {
                name: '新闻资讯',
                key: 'recommend'
            },
            {
                name: '通知公告',
                key: 'game'
            }
        ],
        slideData: [],
        topList: [],
        moreList: [],
        gridList:[
            {
                label:'易资讯',
                icon:gridIcon,
                link:'/yiinfo'
            },
            {
                label:'易查询',
                icon:gridIcon,
                link:'/yisearch'
            },
            {
                label:'易学习',
                icon:gridIcon,
                link:'/yistudy'
            },
            {
                label:'易请假',
                icon:gridIcon,
                link:'/yileave_tea'
            },
            {
                label:'易成长',
                icon:gridIcon,
                link:'/yiup'
            }
        ],
        pannelList: [
            {
                src: 'https://ss2.bdstatic.com/70cFvnSh_Q1YnxGkpoWK1HF6hhy/it/u=690356695,4157418173&fm=26&gp=0.jpg',
                title: '标题一',
                desc: '由各种物质组成的巨型球状天体，叫做星球。星球有一定的形状，有自己的运行轨道。由各种物质组成的巨型球状天体，叫做星球。星球有一定的形状，有自己的运行轨道。',
                url: {
                    path: '/info',
                    replace: false
                },
                meta: {
                    source: '来源信息',
                    date: '时间',
                    other: '其他信息'
                }
            },
            {
                src: 'https://ss2.bdstatic.com/70cFvnSh_Q1YnxGkpoWK1HF6hhy/it/u=690356695,4157418173&fm=26&gp=0.jpg',
                title: '标题二',
                desc: '由各种物质组成的巨型球状天体，叫做星球。星球有一定的形状，有自己的运行轨道。',
                url: {
                    path: '/info',
                    replace: false
                },
                meta: {
                    source: '来源信息',
                    date: '时间',
                    other: '其他信息'
                }
            }
      ],
    },
    getters: {
        categoryKey(state) {
            return state.categoryKey;
        },
        categories(state) {
            return state.categories;
        },
        slideData(state) {
            return state.slideData;
        },
        topList(state) {
            return state.topList;
        },
        moreList(state) {
            return state.moreList;
        },
        gridList(state){
            return state.gridList;
        },pannelList(state){
            return state.pannelList
        }

    },
    mutations: {
        updateSlideData(state, data) {
            state.slideData = data;
        },
        updateTopList(state, data) {
            state.topList = data;
        },
        updateMoreList(state, data) {
            state.moreList = state.moreList.concat(data);
        }
    },
    actions: {
        getTopList(store) {
            Vue.jsonp('http://3g.163.com/touch/jsonp/sy/recommend/0-9.html').then( data => {
                 //console.log(data);
                if (data.code == 200) {
                    let slideData = data.focus.filter( item => {
                        return item.addata == null;
                    } ).map( item => {

                        return {
                            title: item.title,
                            img: item.picInfo[0].url,
                            url: item.link
                        }
                    } );

                    let topList = data.list.filter( item => {
                        return item.addata == null;
                    } ).map( item => {
                        
                        return {
                            title: item.title,
                            src:'https://ss2.bdstatic.com/70cFvnSh_Q1YnxGkpoWK1HF6hhy/it/u=690356695,4157418173&fm=26&gp=0.jpg',
                            desc: item.digest,
                            url:{path:`/yiinfo/artdetail/${item.docid}`,query:item},
                            meta: {
                                source: item.source,
                                date: item.ptime,
                                other: '示例模板'
                            }
                        }
                    } );

                    store.commit('updateSlideData', slideData);
                    store.commit('updateTopList', topList);
                }
            } );
        },

        refreshTopList(store, {refreshKey}) {
            return Vue.jsonp('http://3g.163.com/touch/jsonp/sy/recommend/0-9.html', {
                miss: '00',
                refresh: refreshKey
            })
            .then( data => {
                let topList = data.list.filter( item => {
                    return item.addata == null;
                } ).map( item => {
                    return {
                        title: item.title,
                        src:'https://ss2.bdstatic.com/70cFvnSh_Q1YnxGkpoWK1HF6hhy/it/u=690356695,4157418173&fm=26&gp=0.jpg',
                        desc: item.digest,
                        meta: {
                            source: item.source,
                            date: item.ptime,
                            other: '示例模板'
                        }
                    }
                } );

                store.commit('updateTopList', topList);

                return Promise.resolve(topList.length);
            } )
        },

        loadMoreList(store, {refreshKey, page, prepage}) {
            let start = page*prepage;
            let end = start + prepage;
            return Vue.jsonp(`http://3g.163.com/touch/jsonp/sy/recommend/${start}-${end}.html`, {
                miss: '00',
                refresh: refreshKey
            })
            .then( data => {
                //console.log(data);
                let moreList = data.news.filter( item => {
                    return item.addata == null && item.picInfo.length;
                } ).map( item => {
                    return {
                        title: item.title,
                        src: item.picInfo[0].url,
                        desc: item.digest,
                        url:{path:`/yiinfo/artdetail/${item.docid}`,query:item},
                        meta: {
                            source: item.source,
                            date: item.ptime,
                            other: '示例模板'
                        }
                    }
                } );

               

                store.commit('updateMoreList', moreList);

                return Promise.resolve();
            } )
        }
    },
    modules:{
        yiInfo:infoState,
        yisearch:searchStore,
        yistudy:studyStore,
        yileave:leaveStore
    }

});
